@@ -31,15 +31,15 @@ pub struct WalletDump {
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct WalletData {
     #[serde_as(as = "Vec<(_, _)>")]
-    unspent_coins: BTreeMap<CoinID, CoinDataHeight>,
+    pub unspent_coins: BTreeMap<CoinID, CoinDataHeight>,
     #[serde_as(as = "Vec<(_, _)>")]
-    spent_coins: BTreeMap<CoinID, CoinDataHeight>,
-    tx_in_progress: BTreeMap<HashVal, Transaction>,
-    tx_confirmed: BTreeMap<HashVal, (Transaction, BlockHeight)>,
-    my_covenant: Covenant,
+    pub spent_coins: BTreeMap<CoinID, CoinDataHeight>,
+    pub tx_in_progress: BTreeMap<HashVal, Transaction>,
+    pub tx_confirmed: BTreeMap<HashVal, (Transaction, BlockHeight)>,
+    pub my_covenant: Covenant,
     #[serde(default)]
-    stake_list: BTreeMap<TxHash, StakeDoc>,
-    network: NetID,
+    pub stake_list: BTreeMap<TxHash, StakeDoc>,
+    pub network: NetID,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug)]
